# -*- coding: UTF-8 -*-

# Phatch - Photo Batch Processor
# Copyright (C) 2007-2010  www.stani.be
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see http://www.gnu.org/licenses/

if __name__ == '__main__':
    _ = unicode
    import sys
    sys.path.insert(0, '..\\..')

import wx
from lib.windows import register


SELECT = [_("De&select All"), _("&Select All")]


class Panel(wx.Panel):
    def __init__(self, parent, id, actions, extensions, **options):
        wx.Panel.__init__(self, parent, id, **options)
        self.actions = actions
        self.extensions = extensions
        self.list = wx.CheckListBox(self, -1, choices=extensions)
        self.refresh_list()
        self.select = wx.Button(self, -1, SELECT[0])
        # button sizer
        self.button_sizer = wx.BoxSizer(wx.HORIZONTAL)
        self.button_sizer.Add(self.select, 0, wx.ALL, 8)
        # main sizer
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.list, 1, wx.EXPAND)
        sizer.Add(self.button_sizer, 0)
        self.SetSizer(sizer)
        sizer.Fit(self)
        # events
        self.Bind(wx.EVT_BUTTON, self.on_select, self.select)
        wx.CallAfter(self.select.SetLabel, SELECT[1])

    def on_select(self, event):
        select_all = self.select.GetLabel() == SELECT[1]
        for index in range(len(self.extensions)):
            self.list.Check(index, select_all)
        self.select.SetLabel(SELECT[int(not select_all)])

    def refresh_list(self):
        registered = register.which_registered(
            self.actions.keys(),
            self.extensions,
        )
        for index, extension in enumerate(self.extensions):
            self.list.Check(index, extension in registered)

    def apply_list(self):
        labels = self.actions.keys()
        for index, extension in enumerate(self.extensions):
            if self.list.IsChecked(index):
                register.register_extension(self.actions, extension)
            else:
                register.deregister_extension(labels, extension)


class Dialog(wx.Dialog):
    def __init__(self, parent, id, actions, extensions, **options):
        wx.Dialog.__init__(self, parent, id, **options)
        self.panel = Panel(self, -1, actions, extensions)
        apply = wx.Button(self.panel, wx.ID_APPLY, _("&Apply"))
        close = wx.Button(self.panel, wx.ID_CANCEL, _("&Close"))
        button_sizer = self.panel.button_sizer
        button_sizer.Add(apply, 0, wx.ALL, 8)
        button_sizer.Add(close, 0, wx.ALL, 8)
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.panel, 1, wx.EXPAND)
        self.SetSizer(sizer)
        sizer.Fit(self)
        self.Bind(wx.EVT_BUTTON, self.on_apply, apply)

    def on_apply(self, event):
        self.panel.apply_list()


if __name__ == '__main__':
    actions = {
        'Phatch': '"C:\Program Files\Phatch\phatch.exe"',
        'PhatchInspector': '"C:\Program Files\Phatch\phatch.exe" -n',
    }
    app = wx.PySimpleApp(0)
    frame = wx.Frame(None, -1)
    app.SetTopWindow(frame)
    frame.Show()
    dlg = Dialog(frame, -1,
        actions=actions,
        extensions=['.jpg', '.png'],
    )
    wx.CallAfter(dlg.ShowModal)
    app.MainLoop()
